grib2io.tables.section1 API documentation

# grib2io.tables.section1

View Source

      1table_1_0 = {
      2'0':'Experimental',
      3'1':'Version Implemented on 7 November 2001',
      4'2':'Version Implemented on 4 November 2003',
      5'3':'Version Implemented on 2 November 2005',
      6'4':'Version Implemented on 7 November 2007',
      7'5':'Version Implemented on 4 November 2009',
      8'6':'Version Implemented on 15 September 2010',
      9'7':'Version Implemented on 4 May 2011',
     10'8':'Version Implemented on 8 November 2011',
     11'9':'Version Implemented on 2 May 2012',
     12'10':'Version Implemented on 7 November 2012',
     13'11':'Version Implemented on 8 May 2013',
     14'12':'Version Implemented on 14 November 2013',
     15'13':'Version Implemented on 7 May 2014',
     16'14':'Version Implemented on 5 November 2014',
     17'16':'Version Implemented on 11 November 2015',
     18'17':'Version Implemented on 4 May 2016',
     19'18':'Version Implemented on 2 November 2016',
     20'19':'Version Implemented on 3 May 2017',
     21'20':'Version Implemented on 8 November 2017',
     22'21':'Version Implemented on 2 May 2018',
     23'22':'Version Implemented on 7 November 2018',
     24'23':'Version Implemented on 15 May 2019',
     25'24':'Version Implemented on 06 November 2019',
     26'25':'Pre-operational to be implemented by next amendment',
     27'25':'Version Implemented on 06 May 2020',
     28'26':'Version Implemented on 16 November 2020',
     29'27':'Version Implemented on 16 June 2021',
     30'28':'Version Implemented on 15 November 2021',
     31'29':'Version Implemented on 15 May 2022',
     32'30':'Version Implemented on 15 November 2022',
     33'31':'Version Implemented on 15 June 2023',
     34'32':'Version Implemented on 30 November 2023',
     35'33':'Version Implemented on 28 July 2024',
     36'34':'Version Implemented on 15 November 2024',
     37'35':'Version Implemented on 19 May 2025',
     38'36':'Pre-operational to be implemented by next amendment',
     39'37-254':'Future Versions',
     40'255':'Missing"',
     41}
     42
     43table_1_1 = {
     44'0':'Local tables not used. Only table entries and templates from the current master table are valid.',
     45'1-254':'Number of local table version used.',
     46'255':'Missing',
     47}
     48
     49table_1_2 = {
     50'0':'Analysis',
     51'1':'Start of Forecast',
     52'2':'Verifying Time of Forecast',
     53'3':'Observation Time',
     54'4':'Local Time',
     55'5':'Simulation Start',
     56'6':'Start of Data Assimilation',
     57'7-191':'Reserved',
     58'192-254':'Reserved for Local Use',
     59'255':'Missing',
     60}
     61
     62table_1_3 = {
     63'0':'Operational Products',
     64'1':'Operational Test Products',
     65'2':'Research Products',
     66'3':'Re-Analysis Products',
     67'4':'THORPEX Interactive Grand Global Ensemble (TIGGE)',
     68'5':'THORPEX Interactive Grand Global Ensemble (TIGGE) test',
     69'6':'S2S Operational Products',
     70'7':'S2S Test Products',
     71'8':'Uncertainties in ensembles of regional reanalysis project (UERRA)',
     72'9':'Uncertainties in ensembles of regional reanalysis project (UERRA) Test',
     73'10':'Copernicus Regional Reanalysis',
     74'11':'Copernicus Regional Reanalysis Test',
     75'12':'Destination Earth',
     76'13':'Destination Earth test',
     77'14':'Lead Centre for Global Climate Reanalyses (LC-GCR)',
     78'15':'Lead Centre for Global Climate Reanalyses (LC-GCR) test',
     79'16':'Machine Learning Model Intercomparison Project (MLMIP)',
     80'17':'Machine Learning Model Intercomparison Project (MLMIP) test',
     81'18-191':'Reserved',
     82'192-254':'Reserved for Local Use',
     83'255':'Missing',
     84}
     85
     86table_1_4 = {
     87'0':'Analysis Products',
     88'1':'Forecast Products',
     89'2':'Analysis and Forecast Products',
     90'3':'Control Forecast Products',
     91'4':'Perturbed Forecast Products',
     92'5':'Control and Perturbed Forecast Products',
     93'6':'Processed Satellite Observations',
     94'7':'Processed Radar Observations',
     95'8':'Event Probability',
     96'9':'Experimental Data',
     97'10':'ML Based Forecast',
     98'11-191':'Reserved',
     99'192-254':'Reserved for Local Use',
    100'192':'Experimental Products',
    101'255':'Missing',
    102}
    103
    104table_1_5 = {
    105'0':'Calendar Definition',
    106'1':'Paleontological Offset',
    107'2':'Calendar Definition and Paleontological Offset',
    108'3-32767':'Reserved',
    109'32768-65534':'Reserved for Local Use',
    110'65535':'Missing',
    111}
    112
    113table_1_6 = {
    114'0':'Gregorian',
    115'1':'360-day',
    116'2':'365-day',
    117'3':'Proleptic Gregorian',
    118'4-191':'Reserved',
    119'192-254':'Reserved for Local Use',
    120'255':'Missing',
    121}

table_1_0 = {'0': 'Experimental', '1': 'Version Implemented on 7 November 2001', '2': 'Version Implemented on 4 November 2003', '3': 'Version Implemented on 2 November 2005', '4': 'Version Implemented on 7 November 2007', '5': 'Version Implemented on 4 November 2009', '6': 'Version Implemented on 15 September 2010', '7': 'Version Implemented on 4 May 2011', '8': 'Version Implemented on 8 November 2011', '9': 'Version Implemented on 2 May 2012', '10': 'Version Implemented on 7 November 2012', '11': 'Version Implemented on 8 May 2013', '12': 'Version Implemented on 14 November 2013', '13': 'Version Implemented on 7 May 2014', '14': 'Version Implemented on 5 November 2014', '16': 'Version Implemented on 11 November 2015', '17': 'Version Implemented on 4 May 2016', '18': 'Version Implemented on 2 November 2016', '19': 'Version Implemented on 3 May 2017', '20': 'Version Implemented on 8 November 2017', '21': 'Version Implemented on 2 May 2018', '22': 'Version Implemented on 7 November 2018', '23': 'Version Implemented on 15 May 2019', '24': 'Version Implemented on 06 November 2019', '25': 'Version Implemented on 06 May 2020', '26': 'Version Implemented on 16 November 2020', '27': 'Version Implemented on 16 June 2021', '28': 'Version Implemented on 15 November 2021', '29': 'Version Implemented on 15 May 2022', '30': 'Version Implemented on 15 November 2022', '31': 'Version Implemented on 15 June 2023', '32': 'Version Implemented on 30 November 2023', '33': 'Version Implemented on 28 July 2024', '34': 'Version Implemented on 15 November 2024', '35': 'Version Implemented on 19 May 2025', '36': 'Pre-operational to be implemented by next amendment', '37-254': 'Future Versions', '255': 'Missing"'}
table_1_1 = {'0': 'Local tables not used. Only table entries and templates from the current master table are valid.', '1-254': 'Number of local table version used.', '255': 'Missing'}
table_1_2 = {'0': 'Analysis', '1': 'Start of Forecast', '2': 'Verifying Time of Forecast', '3': 'Observation Time', '4': 'Local Time', '5': 'Simulation Start', '6': 'Start of Data Assimilation', '7-191': 'Reserved', '192-254': 'Reserved for Local Use', '255': 'Missing'}
table_1_3 = {'0': 'Operational Products', '1': 'Operational Test Products', '2': 'Research Products', '3': 'Re-Analysis Products', '4': 'THORPEX Interactive Grand Global Ensemble (TIGGE)', '5': 'THORPEX Interactive Grand Global Ensemble (TIGGE) test', '6': 'S2S Operational Products', '7': 'S2S Test Products', '8': 'Uncertainties in ensembles of regional reanalysis project (UERRA)', '9': 'Uncertainties in ensembles of regional reanalysis project (UERRA) Test', '10': 'Copernicus Regional Reanalysis', '11': 'Copernicus Regional Reanalysis Test', '12': 'Destination Earth', '13': 'Destination Earth test', '14': 'Lead Centre for Global Climate Reanalyses (LC-GCR)', '15': 'Lead Centre for Global Climate Reanalyses (LC-GCR) test', '16': 'Machine Learning Model Intercomparison Project (MLMIP)', '17': 'Machine Learning Model Intercomparison Project (MLMIP) test', '18-191': 'Reserved', '192-254': 'Reserved for Local Use', '255': 'Missing'}
table_1_4 = {'0': 'Analysis Products', '1': 'Forecast Products', '2': 'Analysis and Forecast Products', '3': 'Control Forecast Products', '4': 'Perturbed Forecast Products', '5': 'Control and Perturbed Forecast Products', '6': 'Processed Satellite Observations', '7': 'Processed Radar Observations', '8': 'Event Probability', '9': 'Experimental Data', '10': 'ML Based Forecast', '11-191': 'Reserved', '192-254': 'Reserved for Local Use', '192': 'Experimental Products', '255': 'Missing'}
table_1_5 = {'0': 'Calendar Definition', '1': 'Paleontological Offset', '2': 'Calendar Definition and Paleontological Offset', '3-32767': 'Reserved', '32768-65534': 'Reserved for Local Use', '65535': 'Missing'}
table_1_6 = {'0': 'Gregorian', '1': '360-day', '2': '365-day', '3': 'Proleptic Gregorian', '4-191': 'Reserved', '192-254': 'Reserved for Local Use', '255': 'Missing'}